@@ -542,7 +542,11 @@ static PW_ERROR_TYPE deepin_pw_check_by_conf(const char *user, const char *pw, i
                 break;
             }
         }
-
+        DEBUG("check user name equal password");
+        if (options->min_len >= 8 && options->character_num_required >= 3 && strcmp(user,pw) == 0) {
+            ret = PW_ERR_SAME_AS_USERNAME;
+            break;
+        }
         DEBUG("check is_type_valid");
         ret = is_type_valid(pw, options->character_type, options->character_num_required);
         if (PW_NO_ERR != ret) {
@@ -720,12 +724,13 @@ static const char *err_to_string_by_conf(PW_ERROR_TYPE err, const char *conf_fil
     case PW_ERR_PASSWORD_EMPTY:
         return gettext("The password cannot be empty");
     case PW_ERR_LENGTH_SHORT:
+    case PW_ERR_CHARACTER_TYPE_TOO_FEW:
+    case PW_ERR_SAME_AS_USERNAME:
         num = get_pw_min_character_type_by_conf(0, conf_file);
         character_num = get_pw_min_length_by_conf(0, conf_file);
         snprintf(out_buff,
                  BUFF_SIZE,
-                 gettext("The password must have at least %d characters, and contain at least %d of the four character types: lowercase letters, uppercase letters, numbers, and symbols"),
-                 character_num, num);
+                 gettext("Minimum of %d characters. At least %d types: 0-9, a-z, A-Z and symbols. Different from the username."), character_num, num);
         return out_buff;
     case PW_ERR_LENGTH_LONG:
         len = get_pw_max_length_by_conf(0, conf_file);
@@ -756,14 +761,6 @@ static const char *err_to_string_by_conf(PW_ERROR_TYPE err, const char *conf_fil
         return gettext("Internal error");
     case PW_ERR_USER:
         return gettext("Invalid user");
-    case PW_ERR_CHARACTER_TYPE_TOO_FEW:
-        num = get_pw_min_character_type_by_conf(0, conf_file);
-        character_num = get_pw_min_length_by_conf(0, conf_file);
-        snprintf(out_buff,
-                 BUFF_SIZE,
-                 gettext("The password must have at least %d characters, and contain at least %d of the four character types: lowercase letters, uppercase letters, numbers, and symbols"),
-                 character_num, num);
-        return out_buff;
     case PW_ERR_PW_REPEAT:
         return gettext("It does not meet password rules");
     default:
