@@ -4,7 +4,7 @@
 		<message>
 			<location filename="com.deepin.daemon.passwdconf.modify-config!message" line="0"/>
 			<source>Authentication is required to modify the configuration for password validation</source>
-			<translation>Uwierzytelnienie jest wymagane w celu zmodyfikowania konfiguracji w celu sprawdzenia poprawności hasła </translation>
+			<translation>Uwierzytelnienie jest wymagane w celu zmodyfikowania konfiguracji i walidacji hasła </translation>
 		</message>
 		<message>
 			<location filename="com.deepin.daemon.passwdconf.modify-config!description" line="0"/>
