@@ -58,7 +58,7 @@ const _default_conf default_conf[] = {
         [OS_PROFESSIONAL] =
                 {
                         .min_length = 1,
-                        .max_length = 511,
+                        .max_length = 510,
                         .validate_policy = "1234567890;abcdefghijklmnopqrstuvwxyz;"
                                            "ABCDEFGHIJKLMNOPQRSTUVWXYZ;!\"#$%&'()*+,-./"
                                            ":;<=>?@[\\]^_`{|}~/",
@@ -72,7 +72,7 @@ const _default_conf default_conf[] = {
         [OS_SERVER] =
                 {
                         .min_length = 8,
-                        .max_length = 511,
+                        .max_length = 510,
                         .validate_policy = "1234567890;abcdefghijklmnopqrstuvwxyz;"
                                            "ABCDEFGHIJKLMNOPQRSTUVWXYZ;!\"#$%&'()*+,-./"
                                            ":;<=>?@[\\]^_`{|}~/",
@@ -304,7 +304,7 @@ int update_conf(OS_TYPE os_type) {
 
     if (iniparser_find_entry(dic, "Password:VALIDATE_POLICY") == 0) {
         sprintf(append_string + offset,
-                "VALIDATE_POLICY = \"%s\"\n",
+                "VALIDATE_POLICY = %s\n",
                 default_conf[os_type].validate_policy);
         DEBUG("set VALIDATE_POLICY");
     } else {
